create function fn_vandaag(p_plusmindagen integer) returns timestamp without time zone as $$
    select cast(current_date + p_plusmindagen * interval '1 day' as timestamp without time zone) as result;
$$ language sql
;
create or replace function fnomgget_adviesin (p_keyomgverg integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in (select dnkeyomgvergunningen, 
	   case when dladviespositief = 'T' then dvcodeadviesinstanties || '(+)'
	        when dladviespositief = 'F' then dvcodeadviesinstanties || '(-)'
            else dvcodeadviesinstanties || '(?)' 
		    end dvcodeadviesinstanties
       from
         tbadviezen
       where dnkeyomgvergunningen = p_keyomgverg and ddadviesdatum is not null and ddvervallen is null)  
	   loop
       l_text := l_text || ' ' || rtrim(cur_rec.dvcodeadviesinstanties);
      end loop;
      return ltrim(l_text, ' ');
   end;
   $$ language plpgsql
;
create or replace function fnomgget_adviesuit (p_keyomgverg integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in (select dnkeyomgvergunningen, dvcodeadviesinstanties from tbadviezen
                    where dnkeyomgvergunningen = p_keyomgverg and ddadviesdatum is null and  ddvervallen is null)  
	loop
    l_text := l_text || ' ' || rtrim(cur_rec.dvcodeadviesinstanties);
    end loop;
    return ltrim(l_text, ' ');
  end;
  $$ language plpgsql
;
create or replace function fnhhget_adviesin (p_keyhandhavingen integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
     for cur_rec in (select dnkeyhandhavingen, 
	     case when dladviespositief = 'T' then dvcodeadviesinstanties || '(+)'
	          when dladviespositief = 'F' then dvcodeadviesinstanties || '(-)'
              else dvcodeadviesinstanties || '(?)' 
		      end dvcodeadviesinstanties
         from tbadviezen
         where dnkeyhandhavingen = p_keyhandhavingen and ddadviesdatum is not null and ddvervallen is null) 
	loop
    l_text := l_text || ' ' || rtrim(cur_rec.dvcodeadviesinstanties);
    end loop;
    return ltrim(l_text, ' ');
  end;
  $$ language plpgsql
;
create or replace function fnhhget_adviesuit (p_keyhandhavingen integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in (select dnkeyhandhavingen, dvcodeadviesinstanties from tbadviezen
                    where dnkeyhandhavingen = p_keyhandhavingen  and ddadviesdatum is null and  ddvervallen is null) 
	loop
    l_text := l_text || ' ' || rtrim(cur_rec.dvcodeadviesinstanties);
    end loop;
    return ltrim(l_text, ' ');
  end;
  $$ language plpgsql
;
create or replace function fnomgget_actwerkz (p_keyomgverg integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in ( select   dvwerkzaamheden
              from     tbtoestemmingen 
			  inner join tbsrttoestemming
			  on (tbtoestemmingen.dnkeysrttoestemming = tbsrttoestemming.dnkey)
              where    dnkeyomgvergunningen = p_keyomgverg
              and       dlisvervallen = 'F'
              and  (dlistijdelijk = 'F' or ddgeldigtm >= fn_vandaag(0))
              order by dnkeysrttoestemming)  
	   loop
       l_text := l_text || ' - ' || rtrim(cur_rec.dvwerkzaamheden);
      end loop;
      return ltrim(l_text, ' - ');
   end;
   $$ language plpgsql
;
create or replace function fnomgget_actnaam (p_keyomgverg integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in (select   b.dvtoestemmingnaam
              from     tbtoestemmingen a
			  inner join tbsrttoestemming b
			  on (a.dnkeysrttoestemming = b.dnkey)
              where    a.dnkeyomgvergunningen = p_keyomgverg
              and       a.dlisvervallen = 'F'
              and  (a.dlistijdelijk = 'F' or a.ddgeldigtm >= fn_vandaag(0))
              order by a.dnkeysrttoestemming)  
	   loop
       l_text := l_text || ' - ' || rtrim(cur_rec.dvtoestemmingnaam);
      end loop;
      return ltrim(l_text, ' - ');
   end;
   $$ language plpgsql
;
create or replace function fnomgget_actnmwerkz (p_keyomgverg integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in (select   b.dvtoestemmingnaam, a.dvwerkzaamheden
               from     tbtoestemmingen a
			  inner join tbsrttoestemming b
			  on (a.dnkeysrttoestemming = b.dnkey)
              where    a.dnkeyomgvergunningen = p_keyomgverg
              and       a.dlisvervallen = 'F'
              and  (a.dlistijdelijk = 'F' or a.ddgeldigtm >= fn_vandaag(0))
              order by a.dnkeysrttoestemming)  
	   loop
       l_text := l_text || ' - ' || rtrim(cur_rec.dvtoestemmingnaam) ||': '||rtrim(cur_rec.dvwerkzaamheden);
      end loop;
      return ltrim(l_text, ' - ');
   end;
   $$ language plpgsql
;
CREATE FUNCTION instr(varchar, varchar) RETURNS integer AS $$
DECLARE
    pos integer;
BEGIN
    pos:= instr($1, $2, 1);
    RETURN pos;
END;
$$ LANGUAGE plpgsql STRICT IMMUTABLE
;
CREATE FUNCTION instr(string varchar, string_to_search varchar, beg_index integer)
RETURNS integer AS $$
DECLARE
    pos integer NOT NULL DEFAULT 0;
    temp_str varchar;
    beg integer;
    length integer;
    ss_length integer;
BEGIN
    IF beg_index > 0 THEN
        temp_str := substring(string FROM beg_index);
        pos := position(string_to_search IN temp_str);
        IF pos = 0 THEN
            RETURN 0;
        ELSE
            RETURN pos + beg_index - 1;
        END IF;
    ELSE
        ss_length := char_length(string_to_search);
        length := char_length(string);
        beg := length + beg_index - ss_length + 2;
        WHILE beg > 0 LOOP
            temp_str := substring(string FROM beg FOR ss_length);
            pos := position(string_to_search IN temp_str);

            IF pos > 0 THEN
                RETURN beg;
            END IF;
            beg := beg - 1;
        END LOOP;
        RETURN 0;
    END IF;
END;
$$ LANGUAGE plpgsql STRICT IMMUTABLE
;
CREATE FUNCTION instr(string varchar, string_to_search varchar,
                      beg_index integer, occur_index integer)
RETURNS integer AS $$
DECLARE
    pos integer NOT NULL DEFAULT 0;
    occur_number integer NOT NULL DEFAULT 0;
    temp_str varchar;
    beg integer;
    i integer;
    length integer;
    ss_length integer;
BEGIN
    IF beg_index > 0 THEN
        beg := beg_index;
        temp_str := substring(string FROM beg_index);
        FOR i IN 1..occur_index LOOP
            pos := position(string_to_search IN temp_str);
            IF i = 1 THEN
                beg := beg + pos - 1;
            ELSE
                beg := beg + pos;
            END IF;
            temp_str := substring(string FROM beg + 1);
        END LOOP;
        IF pos = 0 THEN
            RETURN 0;
        ELSE
            RETURN beg;
        END IF;
    ELSE
        ss_length := char_length(string_to_search);
        length := char_length(string);
        beg := length + beg_index - ss_length + 2;
        WHILE beg > 0 LOOP
            temp_str := substring(string FROM beg FOR ss_length);
            pos := position(string_to_search IN temp_str);
            IF pos > 0 THEN
                occur_number := occur_number + 1;

                IF occur_number = occur_index THEN
                    RETURN beg;
                END IF;
            END IF;
            beg := beg - 1;
        END LOOP;
        RETURN 0;
    END IF;
END;
$$ LANGUAGE plpgsql STRICT IMMUTABLE
;
create function fn_ddmaandjjjj(p_datum timestamp without time zone) 
      returns varchar as $$
      select to_char(p_datum,'FMdd TMmonth YYYY') as result;
$$ language sql
;
CREATE OR REPLACE FUNCTION fn_bedrag(p_bedrag float) RETURNS varchar
    LANGUAGE sql
    AS $$
      select case
        when p_bedrag = 0 then null
        else trim(replace(replace(replace(to_char(p_bedrag,'99,999,999,990.99'),'.','X'),',','.'),'X',','))
      end as result;
$$
;
create function fn_datumplus(p_datum timestamp without time zone,p_plusmindagen integer) returns timestamp without time zone as $$
    select cast(p_datum + p_plusmindagen * interval '1 day' as timestamp without time zone) as result;
$$ language sql
;
create or replace function fnovget_adviesin (p_keyovvergunningen integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
     for cur_rec in (select dnkeyovvergunningen, 
	     case when dladviespositief = 'T' then dvcodeadviesinstanties || '(+)'
	          when dladviespositief = 'F' then dvcodeadviesinstanties || '(-)'
              else dvcodeadviesinstanties || '(?)' 
		      end dvcodeadviesinstanties
         from tbadviezen
         where dnkeyovvergunningen = p_keyovvergunningen and ddadviesdatum is not null and ddvervallen is null) 
	loop
    l_text := l_text || ' ' || rtrim(cur_rec.dvcodeadviesinstanties);
    end loop;
    return ltrim(l_text, ' ');
  end;
  $$ language plpgsql
;
create or replace function fnovget_adviesuit (p_keyovvergunningen integer)
  returns varchar as $$
  declare
  cur_rec record; l_text varchar;
  begin
    l_text := '';
    for cur_rec in (select dnkeyovvergunningen, dvcodeadviesinstanties from tbadviezen
                    where dnkeyovvergunningen = p_keyovvergunningen  and ddadviesdatum is null and  ddvervallen is null) 
	loop
    l_text := l_text || ' ' || rtrim(cur_rec.dvcodeadviesinstanties);
    end loop;
    return ltrim(l_text, ' ');
  end;
  $$ language plpgsql
;
create or replace function fn_unaccent(p_str varchar) 
  returns varchar as $$
 declare 
       v_str    varchar; 
   begin 
	    /* wel even UNACCEnT extensie Postgres installeren (per database) 
		zet om:  'ÀÁÂÃÄÅ' in 'AAAAAA', 'ÉÈËÊ' in 'EEEE', 'ÌÍÎÏ'in  'IIII','ÒÓÔÕÖ' in 'OOOOO',
		 'ÙÚÛÜ'in  'UUUU',  'àáâãäå' in 'aaaaaa', 'èéêë' in 'eeee',  'ìíîï' in 'iiii',  'òóôõö' in 'ooooo',  
	     'ùúûü' in 'uuuu', 'Çç' in 'Cc'
		 */
		  v_str := unaccent(p_str);
		return v_str; 
	end;
 $$ language plpgsql
 ;
 create or replace function fn_isposinteger(text) 
 returns integer as $$
 declare x bigint;
 begin
    x = $1::bigint;
	if x < 0 then return 0;
	  else return 1;
	end if;
   exception when others then
    return 0;
 end;
 $$
 strict
 language plpgsql immutable
;
CREATE OR REPLACE FUNCTION fn_datediff(type varchar, date_from timestamp without time zone, date_to timestamp without time zone) RETURNS INTEGER
    LANGUAGE plpgsql
    AS $$
DECLARE age INTERVAL;
BEGIN
    age := age(date_to::date, date_from::date);
    CASE lower(type)
        WHEN 'month' THEN
            RETURN date_part('year', age) * 12 + date_part('month', age);
        WHEN 'year' THEN
            RETURN date_part('year', age);
        WHEN 'day' THEN
            RETURN (date_to::date - date_from::date)::int;
        ELSE
            RETURN null::integer;
    END CASE;
END;
$$
;
create function fn_isposintpolygoon(polygon varchar)
returns integer  AS $$
declare
    posspace integer;
	tempstr varchar;
	poskomma integer;
    nteller integer default 0;	
 begin
    while char_length(polygon) > 0 loop
	         posspace := position(' 'IN polygon);
			 if posspace > 0 then tempstr := substring(polygon,1,posspace - 1);
			 else tempstr := substring(polygon,1);
			 end if;
			 if posspace > 0 then  polygon := substring(polygon,posspace + 1);
			 else polygon := '';
			 end if;
			 poskomma := position(','IN tempstr);
			 if poskomma = 0 then return 0;
			 end if;
             if fn_isposinteger(substring(tempstr,1,poskomma -1)) = 0 then RETURN 0;
			 end if;
			 if fn_isposinteger(substring(tempstr,poskomma + 1)) = 0 then RETURN 0;
			 end if;
			 nteller := nteller + 1;
     end loop;
	 if nteller < 3 then RETURN 0;
	 else return 1;
	 end if;
 end;
$$ LANGUAGE plpgsql 
; 




 
