create or replace view vwadm_database_info as
select
  cast('Wave' as char(4))as produkt,
  cast('3.1.13' as char(10))as databaseversie,
  version() as rdbms
;
create or replace view vwadm_objectcount as
  select
    'TABLECOLUMN' as object,
    count(pg_attribute.*) as aantal,
    'NVT' as status
  from
    pg_attribute inner join pg_class 
	on pg_class.oid = pg_attribute.attrelid
  where
    upper(pg_class.relname) like('TB%')
    and
    pg_class.relkind = 'r'
    and
    pg_attribute.attnum >0
    and
    pg_attribute.attstattarget <0
union
  select
    'VIEWCOLUMN' as object,
    count(pg_attribute.*) as aantal,
    'NVT' as status
  from
    pg_attribute inner join pg_class 
	on pg_class.oid = pg_attribute.attrelid
  where
    upper(pg_class.relname) like('VW%')
    and
    pg_class.relkind = 'v'
    and
    pg_attribute.attnum >0
    and
    pg_attribute.attstattarget <0
union
  select
    'PRIMARY KEY' as object,
    count(conname) as aantal,
    'NVT' as status
  from
    pg_constraint
  where
    contype = 'p'
    and
    upper(conname) like 'CPK_%'
union
  select
    'FOREIGN KEY' as object,
    count(conname) as aantal,
    'NVT' as status
  from
    pg_constraint
  where
    contype = 'f'
    and
    upper(conname) like 'CFK_%'
union
  select
    'NOT NULL' as object,
    count(conname) as aantal,
    'NVT' as status
  from
    pg_constraint
  where
    contype = 'c'
    and
    upper(conname) like 'CNN_%'
union
  select
    'CHECK' as object,
    count(conname) as aantal,
    'NVT' as status
  from
    pg_constraint
  where
    contype = 'c'
    and
    upper(conname) like 'CHK_%'
union
  select
    'FUNCTION' as object,
    count(proname) as aantal,
    'NVT' as status
  from    pg_catalog.pg_namespace n
          inner join pg_catalog.pg_proc p
          on (p.pronamespace = n.oid)
   where n.nspname = 'public'
union
  select
    'DEFAULT' as object,
    count(attname) as aantal,
    'NVT' as status
  from
    pg_attribute
  where
    atthasdef = true
    and
    attnotnull = false
union
  select
    'INDEX' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'i'
    and
    upper(relname)like 'IDX_%'
union
  select
    'INDEXUNIQUE' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'i'
    and
    upper(relname)like 'IDU_%'
union
  select
    'SEQUENCE' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'S'
    and
    upper(relname) like 'TB%'
union
  select
    'VIEW' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'v'
    and
    upper(relname)like 'VW%'
    and
    not upper(relname)like 'VWADM_%'
	and
    not upper(relname)like 'VWBI_%'
union
  select
    'ADMINVIEW' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'v'
    and
    upper(relname)like 'VWADM_%'
union
  select
    'BIVIEW' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'v'
    and
    upper(relname)like 'VWBI_%'
union
  select
    'TABLE' as object,
    count(relname) as aantal,
    'NVT' as status
  from
    pg_class
  where
    relkind = 'r'
    and
    upper(relname) like 'TB%'
order by object
;
create or replace view vwadm_tablecolumncount as
select
  upper(pg_class.relname) as dvtablename,
  count(pg_attribute.*) as dncolumncount
from
    pg_attribute inner join pg_class 
	on pg_class.oid = pg_attribute.attrelid
where
  upper(pg_class.relname) like('TB%')
  and
  pg_class.relkind = 'r'
  and
  pg_attribute.attnum >0
  and
  pg_attribute.attstattarget <0
group by pg_class.relname
;
create or replace view vwadm_viewcolumncount as
select
  upper(pg_class.relname) as dvviewname,
  count(pg_attribute.*) as dncolumncount
from
    pg_attribute inner join pg_class 
	on pg_class.oid = pg_attribute.attrelid
where
  upper(pg_class.relname) like('VW%')
  and
  pg_class.relkind = 'v'
  and
  pg_attribute.attnum >0
  and
  pg_attribute.attstattarget <0
group by pg_class.relname
;
create or replace view vwadm_timestamp as
select
  cast(now() as timestamp without time zone) as ddtimestamp
;
create or replace view vwadm_recordcount as
select 'tb33gemeente' as tabel, count(*) as records from tb33gemeente
union
select 'tbaanvalsplannen' as tabel, count(*) as records from tbaanvalsplannen
union
select 'tbaardbesluit' as tabel, count(*) as records from tbaardbesluit
union
select 'tbaardbeslsoortzaak' tabel, count(*) records from tbaardbeslsoortzaak
union
select 'tbadressoort' as tabel, count(*) as records from tbadressoort
union
select 'tbadviesinstanties' as tabel, count(*) as records from tbadviesinstanties
union
select 'tbadvieswelstand' as tabel, count(*) as records from tbadvieswelstand
union
select 'tbadviezen' as tabel, count(*) as records from tbadviezen
union
select 'tbavpdigitaal' as tabel, count(*) as records from tbavpdigitaal
union
select 'tbavpkopwagens' as tabel, count(*) as records from tbavpkopwagens
union
select 'tbbesluittypes' as tabel, count(*) as records from tbbesluittypes
union
select 'tbbestemcontactennn' as tabel, count(*) as records from tbbestemcontactennn
union
select 'tbbestemmingsplannen' as tabel, count(*) as records from tbbestemmingsplannen
union
select 'tbbestemtoetscriteria' as tabel, count(*) as records from tbbestemtoetscriteria
union
select 'tbbestplancategorie' as tabel, count(*) as records from tbbestplancategorie
union
select 'tbbestrechten' as tabel, count(*) as records from tbbestrechten
union
select 'tbbouwafwgeldbpl' as tabel, count(*) as records from tbbouwafwgeldbpl
union
select 'tbbouwafwnwbpl' as tabel, count(*) as records from tbbouwafwnwbpl
union
select 'tbbouwcontactennn' as tabel, count(*) as records from tbbouwcontactennn
union
select 'tbbouwvergunningen' as tabel, count(*) as records from tbbouwvergunningen
union
select 'tbbouwvrijgeldbplnn' as tabel, count(*) as records from tbbouwvrijgeldbplnn
union
select 'tbbouwvrijnwbplnn' as tabel, count(*) as records from tbbouwvrijnwbplnn
union
select 'tbbouwwerkz' as tabel, count(*) as records from tbbouwwerkz
union
select 'tbbwaantekeningen' as tabel, count(*) as records from tbbwaantekeningen
union
select 'tbbwinstallaties' as tabel, count(*) as records from tbbwinstallaties
union
select 'tbcbsbtwcategorie' as tabel, count(*) as records from tbcbsbtwcategorie
union
select 'tbcbsfincategorie' as tabel, count(*) as records from tbcbsfincategorie
union
select 'tbcbs_gegevens_w011' as tabel, count(*) as records from tbcbs_gegevens_w011
union
select 'tbcbs_gegevens_w015' as tabel, count(*) as records from tbcbs_gegevens_w015
union
select 'tbchecklistnaam' as tabel, count(*) as records from tbchecklistnaam
union
select 'tbchkitbeheer' as tabel, count(*) as records from tbchkitbeheer
union
select 'tbchkitwerk' as tabel, count(*) as records from tbchkitwerk
union
select 'tbcontactadressen' as tabel, count(*) as records from tbcontactadressen
union
select 'tbcontrgebouwtype' as tabel, count(*) as records from tbcontrgebouwtype
union
select 'tbcorafschriften' as tabel, count(*) as records from tbcorafschriften
union
select 'tbcorrespbinnen' as tabel, count(*) as records from tbcorrespbinnen
union
select 'tbcorrespondentie' as tabel, count(*) as records from tbcorrespondentie
union
select 'tbdefafschriften' as tabel, count(*) as records from tbdefafschriften
union
select 'tbdocumenten' as tabel, count(*) as records from tbdocumenten
union
select 'tbdocumentsoorten' as tabel, count(*) as records from tbdocumentsoorten
union
select 'tbdossierverblijf' as tabel, count(*) as records from tbdossierverblijf
union
select 'tbextramemo' as tabel, count(*) as records from tbextramemo
union
select 'tbgebouwen' as tabel, count(*) as records from tbgebouwen
union
select 'tbgebouwspec' as tabel, count(*) as records from tbgebouwspec
union
select 'tbgebouwtype' as tabel, count(*) as records from tbgebouwtype
union
select 'tbgeowms' tabel, count(*) records from tbgeowms
union
select 'tbgroepvergunning' as tabel, count(*) as records from tbgroepvergunning
union
select 'tbhandhafronding' as tabel, count(*) as records from tbhandhafronding
union
select 'tbhandhavingen' as tabel, count(*) as records from tbhandhavingen
union
select 'tbhandhbestmaatr' as tabel, count(*) as records from tbhandhbestmaatr
union
select 'tbhandhcontactennn' as tabel, count(*) as records from tbhandhcontactennn
union
select 'tbhandhinvorderingen' as tabel, count(*) as records from tbhandhinvorderingen
union
select 'tbhandhovertreding' as tabel, count(*) as records from tbhandhovertreding
union
select 'tbhandhprojekten' as tabel, count(*) as records from tbhandhprojekten
union
select 'tbhandhwetbasis' as tabel, count(*) as records from tbhandhwetbasis
union
select 'tbhhafrondsoortzaak' tabel, count(*) records from tbhhafrondsoortzaak
union
select 'tbhhbestmaatregnn' as tabel, count(*) as records from tbhhbestmaatregnn
union
select 'tbhhrechten' as tabel, count(*) as records from tbhhrechten
union
select 'tbhoraardbesluit' as tabel, count(*) as records from tbhoraardbesluit
union
select 'tbhorbeperkingen' as tabel, count(*) as records from tbhorbeperkingen
union
select 'tbhorecacontactennn' as tabel, count(*) as records from tbhorecacontactennn
union
select 'tbhorecavergunningen' as tabel, count(*) as records from tbhorecavergunningen
union
select 'tbhorexploitatie' as tabel, count(*) as records from tbhorexploitatie
union
select 'tbhorgebied' as tabel, count(*) as records from tbhorgebied
union
select 'tbhorklachten' as tabel, count(*) as records from tbhorklachten
union
select 'tbhorlokaliteiten' as tabel, count(*) as records from tbhorlokaliteiten
union
select 'tbhorontheffingen' as tabel, count(*) as records from tbhorontheffingen
union
select 'tbhorrechten' as tabel, count(*) as records from tbhorrechten
union
select 'tbhorrechtsvorm' as tabel, count(*) as records from tbhorrechtsvorm
union
select 'tbhorredenaanvraag' as tabel, count(*) as records from tbhorredenaanvraag
union
select 'tbhorsluitingen' as tabel, count(*) as records from tbhorsluitingen
union
select 'tbhorsluitingstijden' as tabel, count(*) as records from tbhorsluitingstijden
union
select 'tbhorsoortexploitatie' as tabel, count(*) as records from tbhorsoortexploitatie
union
select 'tbhorsoortklacht' as tabel, count(*) as records from tbhorsoortklacht
union
select 'tbhorspautcategorie' as tabel, count(*) as records from tbhorspautcategorie
union
select 'tbhorspeelautomaten' as tabel, count(*) as records from tbhorspeelautomaten
union
select 'tbhorsrtonderneming' as tabel, count(*) as records from tbhorsrtonderneming
union
select 'tbhorterras' as tabel, count(*) as records from tbhorterras
union
select 'tbinbehandelingbij' as tabel, count(*) as records from tbinbehandelingbij
union
select 'tbinfoaanvragen' as tabel, count(*) as records from tbinfoaanvragen
union
select 'tbinfocontactennn' as tabel, count(*) as records from tbinfocontactennn
union
select 'tbinforechten' as tabel, count(*) as records from tbinforechten
union
select 'tbinfotrefwoord' as tabel, count(*) as records from tbinfotrefwoord
union
select 'tbinfotrefwoordennn' as tabel, count(*) as records from tbinfotrefwoordennn
union
select 'tbinitialisatie' as tabel, count(*) as records from tbinitialisatie
union
select 'tbinspaanleiding' as tabel, count(*) as records from tbinspaanleiding
union
select 'tbinspbesturingsmodel' as tabel, count(*) as records from tbinspbesturingsmodel
union
select 'tbinspbezoeken' as tabel, count(*) as records from tbinspbezoeken
union
select 'tbinspecties' as tabel, count(*) as records from tbinspecties
union
select 'tbinsponderwerpen' as tabel, count(*) as records from tbinsponderwerpen
union
select 'tbinsponrechtm' as tabel, count(*) as records from tbinsponrechtm
union
select 'tbinspovertrgebouw' as tabel, count(*) as records from tbinspovertrgebouw
union
select 'tbinspresultaat' as tabel, count(*) as records from tbinspresultaat
union
select 'tbinspsoortbezoek' as tabel, count(*) as records from tbinspsoortbezoek
union
select 'tbinsptermijnoplovertr' as tabel, count(*) as records from tbinsptermijnoplovertr
union
select 'tbinspwaaromovertreding' as tabel, count(*) as records from tbinspwaaromovertreding
union
select 'tbkadastralegem' as tabel, count(*) as records from tbkadastralegem
union
select 'tbklachtafrond' as tabel, count(*) as records from tbklachtafrond
union
select 'tbklachten' as tabel, count(*) as records from tbklachten
union
select 'tbklachternst' as tabel, count(*) as records from tbklachternst
union
select 'tbklachtfreq' as tabel, count(*) as records from tbklachtfreq
union
select 'tbklachtoverlast' as tabel, count(*) as records from tbklachtoverlast
union
select 'tbklachtvorm' as tabel, count(*) as records from tbklachtvorm
union
select 'tbkopproccheck' as tabel, count(*) as records from tbkopproccheck
union
select 'tbkoptoestadv' as tabel, count(*) as records from tbkoptoestadv
union
select 'tblegesberekeningen' as tabel, count(*) as records from tblegesberekeningen
union
select 'tblegesregels' as tabel, count(*) as records from tblegesregels
union
select 'tblegessoort' as tabel, count(*) as records from tblegessoort
union
select 'tblokcrititems' as tabel, count(*) as records from tblokcrititems
union
select 'tblokcritkoppel' as tabel, count(*) as records from tblokcritkoppel
union
select 'tblokcritlijsten' as tabel, count(*) as records from tblokcritlijsten
union
select 'tbmedewdevices' tabel, count(*) records from tbmedewdevices
union
select 'tbmedewerkers' as tabel, count(*) as records from tbmedewerkers
union
select 'tbmedewtiles' tabel, count(*) records from tbmedewtiles
union
select 'tbmiladropslag' as tabel, count(*) as records from tbmiladropslag
union
select 'tbmilbedrijfeinde' as tabel, count(*) as records from tbmilbedrijfeinde
union
select 'tbmilbedrijfsoort' as tabel, count(*) as records from tbmilbedrijfsoort
union
select 'tbmilcertificaten' as tabel, count(*) as records from tbmilcertificaten
union
select 'tbmilcodecertif' as tabel, count(*) as records from tbmilcodecertif
union
select 'tbmilcodedier' as tabel, count(*) as records from tbmilcodedier
union
select 'tbmilcodeenergie' as tabel, count(*) as records from tbmilcodeenergie
union
select 'tbmilcodeivb' as tabel, count(*) as records from tbmilcodeivb
union
select 'tbmilcodesbi' as tabel, count(*) as records from tbmilcodesbi
union
select 'tbmilcodestal' as tabel, count(*) as records from tbmilcodestal
union
select 'tbmilcodestaldier' as tabel, count(*) as records from tbmilcodestaldier
union
select 'tbmilcodestof' as tabel, count(*) as records from tbmilcodestof
union
select 'tbmilcodetrefw' as tabel, count(*) as records from tbmilcodetrefw
union
select 'tbmilcodewetgrond' as tabel, count(*) as records from tbmilcodewetgrond
union
select 'tbmilcontactennn' as tabel, count(*) as records from tbmilcontactennn
union
select 'tbmildiversen' as tabel, count(*) as records from tbmildiversen
union
select 'tbmilemlctstof' as tabel, count(*) as records from tbmilemlctstof
union
select 'tbmilemlctvoorz' as tabel, count(*) as records from tbmilemlctvoorz
union
select 'tbmilemlucht' as tabel, count(*) as records from tbmilemlucht
union
select 'tbmilemstal' as tabel, count(*) as records from tbmilemstal
union
select 'tbmilemwateig' as tabel, count(*) as records from tbmilemwateig
union
select 'tbmilemwater' as tabel, count(*) as records from tbmilemwater
union
select 'tbmilemwatvoorz' as tabel, count(*) as records from tbmilemwatvoorz
union
select 'tbmilenergie' as tabel, count(*) as records from tbmilenergie
union
select 'tbmilgebied' as tabel, count(*) as records from tbmilgebied
union
select 'tbmilinrichtingen' as tabel, count(*) as records from tbmilinrichtingen
union
select 'tbmilivb' as tabel, count(*) as records from tbmilivb
union
select 'tbmiljurindic' as tabel, count(*) as records from tbmiljurindic
union
select 'tbmilkopvergsrt' as tabel, count(*) as records from tbmilkopvergsrt
union
select 'tbmilnagetech' as tabel, count(*) as records from tbmilnagetech
union
select 'tbmilnaleving' as tabel, count(*) as records from tbmilnaleving
union
select 'tbmilopslag' as tabel, count(*) as records from tbmilopslag
union
select 'tbmilrechten' as tabel, count(*) as records from tbmilrechten
union
select 'tbmilsbi' as tabel, count(*) as records from tbmilsbi
union
select 'tbmilsrtdivers' as tabel, count(*) as records from tbmilsrtdivers
union
select 'tbmilsrtlozing' as tabel, count(*) as records from tbmilsrtlozing
union
select 'tbmilsrtopslag' as tabel, count(*) as records from tbmilsrtopslag
union
select 'tbmilsrtvoorz' as tabel, count(*) as records from tbmilsrtvoorz
union
select 'tbmilstatusopslag' as tabel, count(*) as records from tbmilstatusopslag
union
select 'tbmiltrefwoord' as tabel, count(*) as records from tbmiltrefwoord
union
select 'tbmiltypegebied' as tabel, count(*) as records from tbmiltypegebied
union
select 'tbmilurgentie' as tabel, count(*) as records from tbmilurgentie
union
select 'tbmilvergamvbpl' as tabel, count(*) as records from tbmilvergamvbpl
union
select 'tbmilvergcontactennn' as tabel, count(*) as records from tbmilvergcontactennn
union
select 'tbmilvergrechten' as tabel, count(*) as records from tbmilvergrechten
union
select 'tbmilvergunningen' as tabel, count(*) as records from tbmilvergunningen
union
select 'tbmilvergwetgrond' as tabel, count(*) as records from tbmilvergwetgrond
union
select 'tbmilvoorzopslag' as tabel, count(*) as records from tbmilvoorzopslag
union
select 'tbmilwerkz' as tabel, count(*) as records from tbmilwerkz
union
select 'tbmonumenten' as tabel, count(*) as records from tbmonumenten
union
select 'tbnationaliteiten' as tabel, count(*) as records from tbnationaliteiten
union
select 'tbomgbwinstallaties' as tabel, count(*) as records from tbomgbwinstallaties
union
select 'tbomgoloberichten' as tabel, count(*) as records from tbomgoloberichten
union
select 'tbomgpreparaties' as tabel, count(*) as records from tbomgpreparaties
union
select 'tbomgrechten' as tabel, count(*) as records from tbomgrechten
union
select 'tbomgvergbestemtoets' as tabel, count(*) as records from tbomgvergbestemtoets
union
select 'tbomgvergcontactennn' as tabel, count(*) as records from tbomgvergcontactennn
union
select 'tbomgvergunning' as tabel, count(*) as records from tbomgvergunning
union
select 'tbomsinstallaties' as tabel, count(*) as records from tbomsinstallaties
union
select 'tbomskwal' as tabel, count(*) as records from tbomskwal
union
select 'tbomsmeldingen' as tabel, count(*) as records from tbomsmeldingen
union
select 'tbomsoorzaak' as tabel, count(*) as records from tbomsoorzaak
union
select 'tbomssrtmelder' as tabel, count(*) as records from tbomssrtmelder
union
select 'tbomssrtmelding' as tabel, count(*) as records from tbomssrtmelding
union
select 'tbomswvu' as tabel, count(*) as records from tbomswvu
union
select 'tbopenbareruimte' as tabel, count(*) as records from tbopenbareruimte
union
select 'tbovafwgeldbpl' as tabel, count(*) as records from tbovafwgeldbpl
union
select 'tbovafwnwbpl' as tabel, count(*) as records from tbovafwnwbpl
union
select 'tbovcontactennn' as tabel, count(*) as records from tbovcontactennn
union
select 'tbovrechten' as tabel, count(*) as records from tbovrechten
union
select 'tbovvergunningen' as tabel, count(*) as records from tbovvergunningen
union
select 'tbovvrijgeldbplnn' as tabel, count(*) as records from tbovvrijgeldbplnn
union
select 'tbovvrijnwbplnn' as tabel, count(*) as records from tbovvrijnwbplnn
union
select 'tbovwerkz' as tabel, count(*) as records from tbovwerkz
union
select 'tbperceeladressen' as tabel, count(*) as records from tbperceeladressen
union
select 'tbpgs' as tabel, count(*) as records from tbpgs
union
select 'tbportalcolumns' tabel, count(*) records from tbportalcolumns
union
select 'tbportalnames' tabel, count(*) records from tbportalnames
union
select 'tbportaltiles' tabel, count(*) records from tbportalnames
union
select 'tbpreparaties' as tabel, count(*) as records from tbpreparaties
union
select 'tbprocedures' as tabel, count(*) as records from tbprocedures
union
select 'tbproceduressoortplan' as tabel, count(*) as records from tbproceduressoortplan
union
select 'tbprocitems' as tabel, count(*) as records from tbprocitems
union
select 'tbqueries' as tabel, count(*) as records from tbqueries
union
select 'tbrapporten' as tabel, count(*) as records from tbrapporten
union
select 'tbrapportgroep' as tabel, count(*) as records from tbrapportgroep
union
select 'tbrapportparameters' as tabel, count(*) as records from tbrapportparameters
union
select 'tbrechten' as tabel, count(*) as records from tbrechten
union
select 'tbredenaanhouding' as tabel, count(*) as records from tbredenaanhouding
union
select 'tbretouradvies' as tabel, count(*) as records from tbretouradvies
union
select 'tbsession' as tabel, count(*) as records from tbsession
union
select 'tbsoortcorrbinnen' as tabel, count(*) as records from tbsoortcorrbinnen
union
select 'tbsoorthhzaak' tabel, count(*) records from tbsoorthhzaak
union
select 'tbsoorthorverg' as tabel, count(*) as records from tbsoorthorverg
union
select 'tbsoortinfoaanvraag' as tabel, count(*) as records from tbsoortinfoaanvraag
union
select 'tbsoortinvordering' as tabel, count(*) as records from tbsoortinvordering
union
select 'tbsoortmilverg' as tabel, count(*) as records from tbsoortmilverg
union
select 'tbsoortomgverg' as tabel, count(*) as records from tbsoortomgverg
union
select 'tbsoortovverg' as tabel, count(*) as records from tbsoortovverg
union
select 'tbsoortplan' as tabel, count(*) as records from tbsoortplan
union
select 'tbsrtbestplan' as tabel, count(*) as records from tbsrtbestplan
union
select 'tbsrttoestemming' as tabel, count(*) as records from tbsrttoestemming
union
select 'tbtermijnbewstappen' as tabel, count(*) as records from tbtermijnbewstappen
union
select 'tbtoestemmingen' as tabel, count(*) as records from tbtoestemmingen
union
select 'tbupload' as tabel, count(*) as records from tbupload
union
select 'tbverzendlijst' as tabel, count(*) as records from tbverzendlijst
union
select 'tbvrijevelden' as tabel, count(*) as records from tbvrijevelden
union
select 'tbvrijeveldenbetekenissen' as tabel, count(*) as records from tbvrijeveldenbetekenissen
union
select 'tbwagens' as tabel, count(*) as records from tbwagens
union
select 'tbwelstandbeeldkwal' as tabel, count(*) as records from tbwelstandbeeldkwal
union
select 'tbwelstandcommissie' as tabel, count(*) as records from tbwelstandcommissie
union
select 'tbwelstandcriteria' as tabel, count(*) as records from tbwelstandcriteria
union
select 'tbwoonplaats' as tabel, count(*) as records from tbwoonplaats
;
create or replace view vwadm_views as
select
  cast(upper(relname) as character varying(30)) as dvnaam,
  cast(lower(relname) as character varying(30)) as dvviewname,
  cast(obj_description(oid, 'pg_class') as character varying(4000)) as dvcomment
from
  pg_class
where
  relkind = 'v'
  and
  upper(relname)like 'VW%'
;
create or replace view vwadm_tables as
select
  cast(upper(relname) as character varying(30)) as dvnaam,
  cast(lower(relname) as character varying(30)) as dvtablename,
  cast(obj_description(oid, 'pg_class') as character varying(4000)) as dvcomment
from
  pg_class
where
  relkind = 'r'
  and
  upper(relname)like 'TB%'
;
create or replace view vwadm_tablecolumns
as
select
  cast(upper(b.relname)||'.'||upper(a.attname) as character varying(61)) as dvnaam,
  cast(lower(b.relname)||'.'||lower(a.attname) as character varying(61)) as dvcolumnname,
  cast(col_description(b.oid, a.attnum) as character varying(4000))as dvcomment
from
  pg_attribute a
  inner join pg_class b
  on (b.oid = a.attrelid)
where
  upper(b.relname) like('TB%')
  and
  b.relkind = 'r'
  and
  a.attnum >0
  and
  a.attstattarget <0
;
create or replace view vwadm_viewcolumns
as
select
  cast(upper(b.relname)||'.'||upper(a.attname) as character varying(61)) as dvnaam,
  cast(lower(b.relname)||'.'||lower(a.attname) as character varying(61)) as dvcolumnname,
  cast(col_description(b.oid, a.attnum) as character varying(4000)) as dvcomment
from
  pg_attribute a
  inner join pg_class b
  on (b.oid = a.attrelid)
where
  upper(b.relname) like('VW%')
  and
  b.relkind = 'v'
  and
  a.attnum >0
  and
  a.attstattarget <0
;

